@@ -21,7 +21,6 @@
  *
  * Authors:  Alan Hourihane, <alanh@fairlite.demon.co.uk>
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/trident/trident.h,v 1.59 2003/09/05 22:07:28 alanh Exp $ */
 /*#define VBE_INFO*/
 
 #ifndef _TRIDENT_H_
@@ -31,6 +30,8 @@
 #include <string.h>
 #include <math.h>
 
+#include "tridentpcirename.h"
+
 #include "exa.h"
 #include "xf86Cursor.h"
 #include "xaa.h"
@@ -45,6 +46,13 @@
 #include "xf86Pci.h"
 #include "vbe.h"
 
+/* Banked framebuffer only supported on ISA */
+#ifdef HAVE_ISA
+#define LINEAR() (pTrident->Linear)
+#else
+#define LINEAR() (1)
+#endif
+
 #define PCI_CHIP_2200		0x2200
 
 typedef struct {
@@ -62,7 +70,7 @@ typedef struct {
 typedef struct {
     ScrnInfoPtr		pScrn;
     pciVideoPtr		PciInfo;
-    PCITAG		PciTag;
+    uint32_t		PciTag;
     EntityInfoPtr	pEnt;
     ExaDriverPtr	EXADriverPtr;
     int			useEXA;
@@ -77,7 +85,7 @@ typedef struct {
     unsigned char *     IOBase;
     unsigned char *	FbBase;
     long		FbMapSize;
-    IOADDRESS		PIOBase;
+    unsigned long		PIOBase;
     Bool		NoAccel;
     Bool		HWCursor;
     Bool		UsePCIRetry;
@@ -321,8 +329,12 @@ typedef enum {
 
 #define IsPciCard	(pTrident->pEnt->location.type == BUS_PCI)
 
-#define IsPrimaryCard	((xf86IsPrimaryPci(pTrident->PciInfo)) || \
+#ifdef HAVE_ISA
+# define IsPrimaryCard	((xf86IsPrimaryPci(pTrident->PciInfo)) || \
 			 (xf86IsPrimaryIsa()))
+#else
+# define IsPrimaryCard	(xf86IsPrimaryPci(pTrident->PciInfo))
+#endif
 
 #define HAS_DST_TRANS	((pTrident->Chipset == PROVIDIA9682) || \
 			 (pTrident->Chipset == PROVIDIA9685) || \
